\name{superpc.cv}
\alias{superpc.cv}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Cross-validation for  supervised principal components}
\description{
This function uses a form of cross-validation  to  estimate the optimal feature  threshold in supervised principal components
}
\usage{
superpc.cv(fit, data, n.threshold = 20,  n.fold = 10, folds = NULL,   n.components = 3, min.features = 5, max.features = nrow(data$x), compute.fullcv = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{fit}{ Object returned by superpc.train }
  \item{data}{ Data object of form described in superpc.train documentation }
  \item{n.threshold}{Number of thresholds to consider. Default 20.}
  \item{n.fold}{ Number of cross-validation folds. default is around 10
(program pick a convenient value based on the sample size }
  \item{folds}{List of indices  of cross-validation folds (optional)   }
  \item{n.components}{ Number of cross-validation components to use: 1,2 or 3. }
 \item{min.features}{ Minimum number of features to include, in determining
range for threshold. Default 5. }
  \item{max.features}{ Maximum number of features to include, in determining
range for threshold. Default is total number of features in the dataset  }
  \item{compute.fullcv}{ Should full cross-validation also be done? }
}
\details{
 This function uses a form of cross-validation  to  estimate the optimal feature  threshold in supervised principal components. To avoid prolems with
fitting Cox models to samll validation datastes, it uses the "pre-validation"
approach of Tibshirani and Efron (2002)
}
\value{
 list(threshold = th, nonzero = nonzero, scor = out,
        scor.preval = out.preval, folds = folds, featurescores.folds = featurescores.folds,
        v.preval = cur2, type = type, call = this.call)

  \item{threshold }{Vector of thresholds considered}
  \item{nonzero}{Number of features exceeding each value of the threshold}
 \item{scor.preval}{Likelihood ratio scores from pre-validation}
  \item{scor}{Full CV scores}
 \item{folds}{Indices of CV folds used}
\item{featurescores.folds}{Feature scores for each fold}
\item{v.preval}{The pre-validated predictors}
\item{type }{problem type}
 \item{call }{calling sequence}
}
\author{ Eric Bair and Robert Tibshirani  }
\note{ ~~further notes~~ }


\seealso{}
\examples{
set.seed(332)
x<-matrix(rnorm(1000*40),ncol=40)
y<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
status<- sample(c(rep(1,30),rep(0,10)))

featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)


a<- superpc.train(data, type="survival")
aa<-superpc.cv(a,data)
}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line

\eof
\name{superpc.fit.to.outcome}
\alias{superpc.fit.to.outcome}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Fit predictive model using outcome of supervised principal components }
\description{
 Fit predictive model using outcome of supervised principal components, via
either coxph (for surival data) or lm (for regression data)
}
\usage{
superpc.fit.to.outcome(fit, data.test, score, print=TRUE)
}
\arguments{
  \item{fit}{ Object returned by superpc.train }
  \item{data.test}{ Data object for prediction. Same form as data object documented in superpc.train.}  
  \item{score}{Supervised principal component score, from superpc.predict  }
\item{print}{Should a summary of the fit be printed? Default TRUE}
}
\details{
}
\value{
Returns summary of coxph or lm fit
}
\references{ ~put references to the literature/web site here ~ }
\author{ Eric Bair and Robert Tibshirani }
\note{ ~~further notes~~ }

\examples{
set.seed(332)
#generate some data

x<-matrix(rnorm(1000*20),ncol=20)
y<-10+svd(x[1:30,])$v[,1]+ .1*rnorm(20)
ytest<-10+svd(x[1:30,])$v[,1]+ .1*rnorm(20)
status<- sample(c(rep(1,17),rep(0,3)))
status.test<- sample(c(rep(1,17),rep(0,3)))



featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)
data.test<-list(x=x,y=ytest, status=status.test, featurenames= featurenames)



a<- superpc.train(data, type="survival")

fit<- superpc.predict(a, data, data.test, threshold=1.0, n.components=1, prediction.type="continuous")

superpc.fit.to.outcome(a, data, fit$v.pred)
}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line


\eof
\name{superpc-internal}
\title{Internal superpc functions}
\alias{cor.func}
\alias{coxfunc}
\alias{coxscor}
\alias{coxstuff}
\alias{coxvar}
\alias{mysvd}
\description{Internal superpc functions}
\usage{
cor.func(x, y, fudge = median(sd)) 
coxfunc(x, y, status, fudge = median(sd)) 
coxscor(x, y, ic, offset = rep(0, length(y))) 
coxvar(x, y, ic, offset = rep(0, length(y)), coxstuff.obj = NULL) 
mysvd(x, n.components = NULL) 
}
\author{Eric Bair and Rob Tibshirani}
\details{
  These are not to be called by the user.
}
\keyword{internal}


\eof
\name{superpc.listfeatures}
\alias{superpc.listfeatures}
\title{ Return a list of the important predictors }
\description{
 Return a list of the important predictor
}
\usage{
superpc.listfeatures(data, train.obj, fitred, component.number, shrinkage)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{Data object }
  \item{train.obj}{Object returned by superpc.train}
  \item{fitred}{Object returned by superpc.predict.red}
  \item{component.number}{ Index of principal component to use (1,2, or 3) }
  \item{shrinkage}{Amount of shrinkage  }
 }
}
\details{
}
\value{
Returns matrix of features and their importance scores, in order
of decreasing absolute value of importance score. The importance score
is the correlation of the reduced predictor and the full supervised PC
predictor. It also lists the raw score- for survival data, this is the Cox score
for that feature; for regression, it is the standardized regression coefficient.
}
\author{Eric Bair and Rob Tibshirani}


\examples{
#generate some data

x<-matrix(rnorm(1000*40),ncol=40)
y<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
ytest<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
status<- sample(c(rep(1,30),rep(0,10)))
status.test<- sample(c(rep(1,30),rep(0,10)))
featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)
data.test<-list(x=x,y=ytest, status=status.test, featurenames= featurenames)

a<- superpc.train(data, type="survival")

fit<- superpc.predict(a, data, data.test, threshold=1.0, n.components=1, prediction.type="continuous")

fit.red<- superpc.predict.red(a,data, data.test, .6)
superpc.listfeatures(data, a,  fit.red,1,shrinkage=0.3)

}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line

\eof
\name{superpc.lrtest.curv}
\alias{superpc.lrtest.curv}
\title{ Compute values of likelihood ratio test  from supervised  principal components fit }
\description{
Compute values of likelihood ratio test  from supervised  principal components fit 
}
\usage{
superpc.lrtest.curv(object, data, newdata, n.components = 1, threshold = NULL, n.threshold = 20)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
\item{object}{ Object returned by superpc.train }
\item{data}{ List of training data, of form described in superpc.train documentation}
 \item{newdata}{ List of test data; same form as training data }
  \item{n.components}{ Number of principal components to compute. Should be 1,2 or 3. }
 \item{threshold}{ Set of thresholds for scoresL default is n.threshold values equally spaced over the range of the feature scores}
  \item{n.threshold}{ Number of thresholds to use; default 20. Should be 1,2 or 3. }
}
\details{
}
\value{
  If it is a LIST, use
  \item{lrtest }{Values of likelihood ratio test statistic}
  \item{comp2 }{Description of 'comp2'}
 \item{threshold}{ Thresholds used}
\item{num.features}{Number of features exceeding threshold}
\item{type}{Type of outcome variable}
\item{call}{calling sequence}
}
\references{ ~put references to the literature/web site here ~ }
\author{ Eric Bair and Robert Tibshirani }

\note{ ~~further notes~~ }


\seealso{}
\examples{
set.seed(332)
#generate some data

x<-matrix(rnorm(1000*20),ncol=20)
y<-10+svd(x[1:30,])$v[,1]+ .1*rnorm(20)
ytest<-10+svd(x[1:30,])$v[,1]+ .1*rnorm(20)
status<- sample(c(rep(1,17),rep(0,3)))
status.test<- sample(c(rep(1,17),rep(0,3)))

featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)
data.test<-list(x=x,y=ytest, status=status.test, featurenames= featurenames)


a<- superpc.train(data, type="survival")

fit<- superpc.predict(a, data, data.test, threshold=1.0, n.components=1, prediction.type="continuous")


aa<- superpc.lrtest.curv(a, data, data.test)
superpc.plot.lrtest(aa)
}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line

\eof
\name{superpc.plot.lrtest}
\alias{superpc.plot.lrtest}
\title{ Plot likelhiood ratio test statistics}
\description{
Plot likelhiood ratio test statistics from output of superpc.predict
}
\usage{
superpc.plot.lrtest(object.lrtestcurv)
}
\arguments{
  \item{object.lrtestcurv}{Output from superpc.lrtest.curv}
}
\details{
}
\value{
}
\author{ Eric Bair and Robert Tibshirani }


\seealso{}
\examples{

set.seed(332)
#generate some data

x<-matrix(rnorm(1000*40),ncol=40)
y<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
ytest<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
status<- sample(c(rep(1,30),rep(0,10)))
status.test<- sample(c(rep(1,30),rep(0,10)))

featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)
data.test<-list(x=x,y=ytest, status=status.test, featurenames= featurenames)



a<- superpc.train(data, type="survival")
aa<-superpc.cv(a, data)

fit<- superpc.predict(a, data, data.test, threshold=1.0, n.components=1, prediction.type="continuous")


bb<-superpc.lrtest.curv(a,data,data.test)

superpc.plot.lrtest(bb)

}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line

\eof
\name{superpc.plotcv}
\alias{superpc.plotcv}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Plot output from superpc.cv}
\description{
Plots pre-validation results from plotcv, to aid in choosing best threshold
}
\usage{
superpc.plotcv(object, smooth = TRUE, smooth.df = 6, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{object}{ Object returned by superpc.cv }
  \item{smooth}{ Should plot be smoothed? Default TRUE. }
  \item{smooth.df}{ Degrees of freedom for smooth.spline, default 6.
If NULL, then degrees of freedom is estimated by cross-validation.}
  \item{\dots}{ Additional plotting args to be passed to matplot }
}
\details{
}
\value{
}
\author{ Eric Bair and Robert Tibshirani}


\seealso{}
\examples{
set.seed(332)
x<-matrix(rnorm(1000*40),ncol=40)
y<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
status<- sample(c(rep(1,30),rep(0,10)))

featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)


a<- superpc.train(data, type="survival")
aa<-superpc.cv(a,data)

superpc.plotcv(aa)

}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line

\eof
\name{superpc.plotshrink.lrtest}
\alias{superpc.plotshrink.lrtest}
\title{ Plot likelihood ratio test statistics from
supervised principal components predictor }
\description{
Plot likelihood ratio test statistics from
supervised principal components predictor}

\usage{
superpc.plotshrink.lrtest(object.lrtestred)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{object.lrtestred}{ Output from either superpc.predict.red
or superpc.predict.redcv }
}
\details{
}
\value{
}
\references{ ~put references to the literature/web site here ~ }
\author{ Eric Bair and Robert Tibshirani }
\note{ ~~further notes~~ }


\seealso{}
\examples{
set.seed(332)
#generate some data

x<-matrix(rnorm(1000*40),ncol=40)
y<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
ytest<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
status<- sample(c(rep(1,30),rep(0,10)))
status.test<- sample(c(rep(1,30),rep(0,10)))

featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)
data.test<-list(x=x,y=ytest, status=status.test, featurenames= featurenames)


a<- superpc.train(data, type="survival")
aa<-superpc.cv(a, data)

fit<- superpc.predict(a, data, data.test, threshold=1.0, n.components=1, prediction.type="continuous")


fit.red<- superpc.predict.red(a, data, data.test, .6)

fit.redcv<- superpc.predict.red.cv(fit.red, aa,  data,  .6)

superpc.plotshrink.lrtest(fit.redcv)

}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line

\eof
\name{superpc.predict}
\alias{superpc.predict}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Form principal components predictor from a trained superpc object}
\description{
Computes supervised principal components, using scores from "object"
}
\usage{
superpc.predict(object, data, newdata, threshold, n.components = 1, prediction.type = c("continuous", "discrete", "nonzero"), n.class = 2)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{object}{ Obect returned by superpc.train }
  \item{data}{ List of training data, of form described in superpc.train documentation, }
  \item{newdata}{ List of test data; same form as training data }
  \item{threshold}{ Threshold for scores: features with abs(score)>trheshold
are retained. }
  \item{n.components}{ Number of principal components to compute.
Should be 1,2 or 3. }
  \item{prediction.type}{ "continuous" for raw principal component(s);
"discrete" for principal component categorized in equal bins;
"nonzero" for indices of features that pass the threshold }
  \item{n.class}{ Number of classes into which predictor is binned
(for prediction.type="discrete" }
}
\details{
}
\value{
  \item{v.pred }{Supervised principal componients predictor}
  \item{u }{U matrix from svd of feature matrix x}
  \item{d }{singual values  from svd of feature matrix x}
 \item{which.features}{Indices of features exceeding threshold}
 \item{n.components}{Number of supervised  principal components requested}
\item{call}{calling sequence}
}
\author{ Eric Bair and Robert Tibshirani }



\examples{
set.seed(332)
#generate some data

x<-matrix(rnorm(1000*20),ncol=20)
y<-10+svd(x[1:30,])$v[,1]+ .1*rnorm(20)
ytest<-10+svd(x[1:30,])$v[,1]+ .1*rnorm(20)
status<- sample(c(rep(1,17),rep(0,3)))
status.test<- sample(c(rep(1,17),rep(0,3)))

featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)
data.test<-list(x=x,y=ytest, status=status.test, featurenames= featurenames)


a<- superpc.train(data, type="survival")

fit<- superpc.predict(a, data, data.test, threshold=1.0, n.components=1, prediction.type="continuous")

plot(fit$v.pred,ytest)

}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line

\eof
\name{superpc.predict.red}
\alias{superpc.predict.red}
\title{Feature selection for supervised principal components }
\description{ 
Forms  reduced models involving a subset of the features, by
soft-thresholding of correlations between the  features and the
supervised principal component predictor.
}
\usage{
superpc.predict.red(fit, data, data.test, threshold, n.components = 1, n.shrinkage = 20, compute.lrtest = TRUE, sign.wt = "both")
}
\arguments{
  \item{fit}{ Object returned by superpc.train}
  \item{data}{ Training data object, of form described in superpc.train dcoumentation }
  \item{data.test}{ Test data object; same form as train  }
  \item{threshold}{ Feature score threshold; usually estimated from superpc.cv}
  \item{n.components}{ Number of principal components to use.
Should be 1,2 or 3. }
  \item{n.shrinkage}{ Number of shrinkage values to consider. Default 20. }
  \item{compute.lrtest}{ Should the likelihood ratio test be computed? Default TRUE  }
  \item{sign.wt}{Allowable signs for feature weights. Can be "both",
"positive",  or "negative". Default: "both"  }
}
\details{
}
\value{
  ~Describe the value returned
  If it is a LIST, use
\item{shrinkages}{Shrinkage values used}
\item{lrtest.shrink}{ Likeihood ratio tests for reduced models }
\item{corr.with.full }{ Correlation of each reducted predictor with full
superivsed PC predictor}
\item{num.features}{Number of features used in each shrunken model}
\item{features.list}{ Indiced of features used}
\item{import}{Importance scores for features}
\item{v.test}{Outcome predictor from reduced models. Array of
n.shrinkage by (number of test observations) by n.components}
\item{n.components }{Number of supervised  principal component used}
\item{sign.wt}{Allowable signs for feature weights}
\item{type }{Type of outcome}
\item{call}{calling sequence}
}
\references{ ~put references to the literature/web site here ~ }
\author{ Eric Bair and Robert Tibshirani }
\note{ ~~further notes~~ }


\seealso{}
\examples{


set.seed(332)
#generate some data

x<-matrix(rnorm(1000*40),ncol=40)
y<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
ytest<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
status<- sample(c(rep(1,30),rep(0,10)))
status.test<- sample(c(rep(1,30),rep(0,10)))

featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)
data.test<-list(x=x,y=ytest, status=status.test, featurenames= featurenames)



a<- superpc.train(data, type="survival")

fit<- superpc.predict(a, data, data.test, threshold=1.0, n.components=1, prediction.type="continuous")

fit.red<- superpc.predict.red(a,data, data.test, .6)

superpc.fit.to.outcome(a, data.test, fit.red$v.test[5,,])
}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line


\eof
\name{superpc.predict.red.cv}
\alias{superpc.predict.red.cv}
\title{Cross-validation of feature selection for supervised principal components }
\description{
Applies superpc.predict.red to cross-validation folds generates in superpc.cv.
Uses the output to evaluate reduced models, and compare them to the
full supervised principal components predictor.
}
\usage{
superpc.predict.red.cv(fitred, fitcv, data, threshold, n.shrinkage = 30, sign.wt = "both")
}
\arguments{
  \item{fitred}{ Output of superpc.predict.red}
  \item{fitcv}{ Output of superpc.cv }
  \item{data}{ Training data object }
  \item{threshold}{Feature score threshold; usually estimated from superpc.cv}
  \item{n.shrinkage}{Number of shrinkage values to consider. Default 20.}
  \item{sign.wt}{ Allowable signs for feature weights. Can be "both",
"positive",  or "negative". Default: "both" }
}
\details{
}
\value{
\item{shrinkages}{Shrinkage values used}
\item{lrtest.shrink}{ Likeihood ratio tests for reduced models }
\item{num.features}{Number of features used in each shrunken model}
\item{n.components }{Number of supervised  principal components used}

\item{v.preval.red}{Outcome predictor from reduced models. Array of
n.shrinkage by (number of test observations) by n.components}
\item{n.components }{Number of supervised  principal component used}
\item{sign.wt}{Allowable signs for feature weights}
\item{type }{Type of outcome}
\item{call}{calling sequence}
}

\references{ ~put references to the literature/web site here ~ }
\author{ Eric Bair and Robert Tibshirani }
\note{ ~~further notes~~ }


\seealso{}
\examples{


set.seed(332)
#generate some data

x<-matrix(rnorm(1000*40),ncol=40)
y<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
ytest<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
status<- sample(c(rep(1,30),rep(0,10)))
status.test<- sample(c(rep(1,30),rep(0,10)))

featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)
data.test<-list(x=x,y=ytest, status=status.test, featurenames= featurenames)



a<- superpc.train(data, type="survival")
aa<-superpc.cv(a, data)

fit<- superpc.predict(a, data, data.test, threshold=1.0, n.components=1, prediction.type="continuous")

fit.red<- superpc.predict.red(a,data, data.test, .6)

fit.redcv<- superpc.predict.red.cv(fit.red, aa,  data,  .6)


}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line

\eof
\name{superpc.train}
\alias{superpc.train}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Prediction by supervised principal components}
\description{
Does prediction of a quantitative  regression 
or survival outcome, by the supervised principal components
method.
}
\usage{
superpc.train(data, type = c("survival", "regression"))
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{ Data object with components x- p by n matrix of features,
one observation per column; y- n-vector of outcome measurements;
status- n-vector of censoring status (1= died or event occurred, 0=survived, or event was censored), needed
for a censored survival outcome}
  \item{type}{Problem type:  "survival" for censored survival outcome, or "regression"
for simple quantitative outcome}
}
\details{ Compute wald scores for each feature (gene), for later use in 
superpc.predict and superpc.cv
}
\value{
 gene.scores=gene.scores, 
               type=type, 
               call = this.call
  \item{feature.scores }{Score for each feature (gene)}
  \item{type }{problem type}
 \item{call }{calling sequence}
}
\references{Bair E, Tibshirani R (2004) Semi-supervised methods to predict patient survival from gene expression data. PLoS Biol 2004 April; 2 (4): e108;
http://www-stat.stanford.edu/~tibs/superpc}
\author{ Eric Bair and Robert Tibshirani }


\examples{
#generate some example data
set.seed(332)
x<-matrix(rnorm(1000*40),ncol=40)
y<-10+svd(x[1:60,])$v[,1]+ .1*rnorm(40)
status<- sample(c(rep(1,30),rep(0,10)))

featurenames <- paste("feature",as.character(1:1000),sep="")
data<-list(x=x,y=y, status=status, featurenames=featurenames)


a<- superpc.train(data, type="survival")
}
\keyword{regression}% at least one, from doc/KEYWORDS
\keyword{survival}% __ONLY ONE__ keyword per line

\eof
